==> haskell-tasty-1.1.0.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty
version: 1.1.0.3
id: tasty-1.1.0.3-FF9Bf2Xp2BG6DZ1uQXD9sH
key: tasty-1.1.0.3-FF9Bf2Xp2BG6DZ1uQXD9sH
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: Modern and extensible testing framework
description:
    Tasty is a modern testing framework for Haskell.
    It lets you combine your unit tests, golden
    tests, QuickCheck/SmallCheck properties, and any
    other types of tests into a single test suite.
category: Testing
abi: 82080caf5dc3107fc22e84ac0a1da579
exposed: True
exposed-modules:
    Test.Tasty Test.Tasty.Ingredients Test.Tasty.Ingredients.Basic
    Test.Tasty.Ingredients.ConsoleReporter Test.Tasty.Options
    Test.Tasty.Patterns.Eval Test.Tasty.Patterns.Parser
    Test.Tasty.Patterns.Types Test.Tasty.Providers Test.Tasty.Runners
hidden-modules: Test.Tasty.Parallel Test.Tasty.Core
                Test.Tasty.Options.Core Test.Tasty.Options.Env Test.Tasty.Patterns
                Test.Tasty.Patterns.Expr Test.Tasty.Run Test.Tasty.Runners.Reducers
                Test.Tasty.Runners.Utils Test.Tasty.CmdLine
                Test.Tasty.Ingredients.ListTests
                Test.Tasty.Ingredients.IncludingOptions
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-1.1.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-1.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-1.1.0.3
hs-libraries: HStasty-1.1.0.3-FF9Bf2Xp2BG6DZ1uQXD9sH
depends:
    base-4.11.1.0 stm-2.4.5.0 containers-0.5.11.0 mtl-2.2.2
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU
    unbounded-delays-0.1.1.0-9rdvMSlv4bPE477VFM26yN
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs unix-2.7.2.2
    wcwidth-0.0.2-Df9Czl4wr4mFBBYPyfd34r
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             optparse-applicative-0.14.2.0-2eDVpgsAe1xL6LOfCGKJrU=167699d54d61d2b1b6c082fc4a9ddc9b
             unbounded-delays-0.1.1.0-9rdvMSlv4bPE477VFM26yN=5e02d6700e417991a67e203e0b19e096
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG=eaed657d24f75590faf3b67ce55e7410
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=6b9ed802e71695075777b6e69687e9b7
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
             wcwidth-0.0.2-Df9Czl4wr4mFBBYPyfd34r=7ae65af2f1c97253af0ea2d8ace33370
haddock-interfaces: /usr/share/doc/haskell-tasty/html/tasty.haddock
haddock-html: /usr/share/doc/haskell-tasty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-1.1.0.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty
version: 1.1.0.3
id: tasty-1.1.0.3-DfrquUrmEWG90mJgnRwHvl
key: tasty-1.1.0.3-DfrquUrmEWG90mJgnRwHvl
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: Modern and extensible testing framework
description:
    Tasty is a modern testing framework for Haskell.
    It lets you combine your unit tests, golden
    tests, QuickCheck/SmallCheck properties, and any
    other types of tests into a single test suite.
category: Testing
abi: 814f05a0ef2ec67b11f2b4b960c24978
exposed: True
exposed-modules:
    Test.Tasty Test.Tasty.Ingredients Test.Tasty.Ingredients.Basic
    Test.Tasty.Ingredients.ConsoleReporter Test.Tasty.Options
    Test.Tasty.Patterns.Eval Test.Tasty.Patterns.Parser
    Test.Tasty.Patterns.Types Test.Tasty.Providers Test.Tasty.Runners
hidden-modules: Test.Tasty.Parallel Test.Tasty.Core
                Test.Tasty.Options.Core Test.Tasty.Options.Env Test.Tasty.Patterns
                Test.Tasty.Patterns.Expr Test.Tasty.Run Test.Tasty.Runners.Reducers
                Test.Tasty.Runners.Utils Test.Tasty.CmdLine
                Test.Tasty.Ingredients.ListTests
                Test.Tasty.Ingredients.IncludingOptions
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-1.1.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-1.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-1.1.0.3
hs-libraries: HStasty-1.1.0.3-DfrquUrmEWG90mJgnRwHvl
depends:
    base-4.11.1.0 stm-2.4.5.0 containers-0.5.11.0 mtl-2.2.2
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    optparse-applicative-0.14.2.0-K7gRnp080wgGVRM5iNUBl1
    unbounded-delays-0.1.1.0-9rdvMSlv4bPE477VFM26yN
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    ansi-terminal-0.8.1-92I6zmeqYXE2HtFhEfFRK6
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs unix-2.7.2.2
    wcwidth-0.0.2-Df9Czl4wr4mFBBYPyfd34r
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             optparse-applicative-0.14.2.0-K7gRnp080wgGVRM5iNUBl1=f23942b3b87da5fbba8d301e58fc899a
             unbounded-delays-0.1.1.0-9rdvMSlv4bPE477VFM26yN=5e02d6700e417991a67e203e0b19e096
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             ansi-terminal-0.8.1-92I6zmeqYXE2HtFhEfFRK6=892601395148dacdd997061542e42ef5
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=6b9ed802e71695075777b6e69687e9b7
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
             wcwidth-0.0.2-Df9Czl4wr4mFBBYPyfd34r=7ae65af2f1c97253af0ea2d8ace33370
haddock-interfaces: /usr/share/doc/haskell-tasty/html/tasty.haddock
haddock-html: /usr/share/doc/haskell-tasty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
